grid_helper.Rd
Build a vector between the minimum and maximum ensuring that the given origin value is part of the returned vector.
grid_helper(o, min, max, res)
a numeric(1). Origin.
a numeric(1). Mininum value.
a numeric(1). Maximum value.
a numeric(1). Resultuion.
A numeric.